@@ -1082,7 +1082,10 @@ _gth_browser_update_open_menu (GthBrowser *browser,
 		gtk_widget_show (menu_item);
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
 
-		g_object_set_data (G_OBJECT (menu_item), "appinfo", appinfo);
+		g_object_set_data_full (G_OBJECT (menu_item),
+					"appinfo",
+					g_object_ref (appinfo),
+					g_object_unref);
 		g_signal_connect (menu_item,
 				  "activate",
 				  G_CALLBACK (activate_open_with_application_item),
@@ -1105,7 +1108,7 @@ _gth_browser_update_open_menu (GthBrowser *browser,
 	gtk_widget_show (openwith_item);
 
 	g_hash_table_destroy (used_apps);
-	g_list_free (appinfo_list);
+	_g_object_list_unref (appinfo_list);
 	_g_object_list_unref (file_list);
 	_gtk_tree_path_list_free (items);
 }
