@@ -43,38 +43,48 @@ enum {
 
 
 static guint signals[LAST_SIGNAL] = { 0 };
-static gpointer parent_class = NULL;
+
+
+static void gth_image_rotator_gth_image_tool_interface_init (GthImageViewerToolInterface *iface);
+
+
+G_DEFINE_TYPE_WITH_CODE (GthImageRotator,
+			 gth_image_rotator,
+			 G_TYPE_OBJECT,
+			 G_IMPLEMENT_INTERFACE (GTH_TYPE_IMAGE_VIEWER_TOOL,
+					        gth_image_rotator_gth_image_tool_interface_init))
+
 
 
 struct _GthImageRotatorPrivate {
-	GthImageViewer     *viewer;
+	GthImageViewer        *viewer;
 
 	/* options */
 
-	GdkPoint            center;
-	double              angle;
-	cairo_color_t       background_color;
-	gboolean            enable_crop;
-	GdkRectangle        crop_region;
-	GthGridType         grid_type;
-	GthTransformResize  resize;
+	GdkPoint               center;
+	double                 angle;
+	cairo_color_t          background_color;
+	gboolean               enable_crop;
+	cairo_rectangle_int_t  crop_region;
+	GthGridType            grid_type;
+	GthTransformResize     resize;
 
 	/* utility variables */
 
-	int                 original_width;
-	int                 original_height;
-	double              preview_zoom;
-	cairo_surface_t    *preview_image;
-	GdkRectangle        preview_image_area;
-	GdkPoint            preview_center;
-	GdkRectangle        clip_area;
-	cairo_matrix_t      matrix;
-	gboolean            dragging;
-	double              angle_before_dragging;
-	GdkPoint            drag_p1;
-	GdkPoint            drag_p2;
-	GthFit              original_fit_mode;
-	gboolean            original_zoom_enabled;
+	int                    original_width;
+	int                    original_height;
+	double                 preview_zoom;
+	cairo_surface_t       *preview_image;
+	cairo_rectangle_int_t  preview_image_area;
+	GdkPoint               preview_center;
+	cairo_rectangle_int_t  clip_area;
+	cairo_matrix_t         matrix;
+	gboolean               dragging;
+	double                 angle_before_dragging;
+	GdkPoint               drag_p1;
+	GdkPoint               drag_p2;
+	GthFit                 original_fit_mode;
+	gboolean               original_zoom_enabled;
 };
 
 
@@ -93,7 +103,7 @@ gth_image_rotator_set_viewer (GthImageViewerTool *base,
 
 	cursor = gdk_cursor_new (GDK_LEFT_PTR);
 	gth_image_viewer_set_cursor (self->priv->viewer, cursor);
-	gdk_cursor_unref (cursor);
+	g_object_unref (cursor);
 }
 
 
@@ -137,10 +147,10 @@ _cairo_matrix_transform_point (cairo_matrix_t *matrix,
 
 
 static void
-gth_transform_resize (cairo_matrix_t     *matrix,
-		      GthTransformResize  resize,
-		      GdkRectangle       *original,
-		      GdkRectangle       *boundary)
+gth_transform_resize (cairo_matrix_t        *matrix,
+		      GthTransformResize     resize,
+		      cairo_rectangle_int_t *original,
+		      cairo_rectangle_int_t *boundary)
 {
 	int x1, y1, x2, y2;
 
@@ -291,10 +301,9 @@ paint_image (GthImageRotator *self,
 
 static void
 paint_darker_background (GthImageRotator *self,
-			 GdkEventExpose  *event,
 			 cairo_t         *cr)
 {
-	GdkRectangle crop_region;
+	cairo_rectangle_int_t crop_region;
 
 	cairo_save (cr);
 	cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.5);
@@ -346,10 +355,9 @@ paint_darker_background (GthImageRotator *self,
 
 static void
 paint_grid (GthImageRotator *self,
-	    GdkEventExpose  *event,
 	    cairo_t         *cr)
 {
-	GdkRectangle grid;
+	cairo_rectangle_int_t grid;
 
 	cairo_save (cr);
 
@@ -366,7 +374,6 @@ paint_grid (GthImageRotator *self,
 
 static void
 paint_point (GthImageRotator *self,
-	     GdkEventExpose  *event,
 	     cairo_t         *cr,
 	     GdkPoint        *p)
 {
@@ -381,28 +388,24 @@ paint_point (GthImageRotator *self,
 
 
 static void
-gth_image_rotator_expose (GthImageViewerTool *base,
-			  GdkEventExpose     *event,
-			  cairo_t            *cr)
+gth_image_rotator_draw (GthImageViewerTool *base,
+			cairo_t            *cr)
 {
 	GthImageRotator *self = GTH_IMAGE_ROTATOR (base);
-	GtkStyle        *style;
+	GtkStyleContext *style_context;
+	GdkRGBA          color;
 	GtkAllocation    allocation;
 
 	cairo_save (cr);
 
-  	cairo_rectangle (cr,
-  			 event->area.x,
-  			 event->area.y,
-  			 event->area.width,
-  			 event->area.height);
-  	cairo_clip (cr);
-
   	/* background */
 
-	style = gtk_widget_get_style (GTK_WIDGET (self->priv->viewer));
+	style_context = gtk_widget_get_style_context (GTK_WIDGET (self->priv->viewer));
+	gtk_style_context_get_background_color (style_context,
+						gtk_widget_get_state (GTK_WIDGET (self->priv->viewer)),
+						&color);
+	gdk_cairo_set_source_rgba (cr, &color);
 	gtk_widget_get_allocation (GTK_WIDGET (self->priv->viewer), &allocation);
-	gdk_cairo_set_source_color (cr, &style->bg[GTK_STATE_NORMAL]);
 	cairo_rectangle (cr, 0, 0, allocation.width, allocation.height);
 	cairo_fill (cr);
 
@@ -426,8 +429,8 @@ gth_image_rotator_expose (GthImageViewerTool *base,
 
 	paint_image (self, cr);
 	if (self->priv->enable_crop) {
-		paint_darker_background (self, event, cr);
-		paint_grid (self, event, cr);
+		paint_darker_background (self, cr);
+		paint_grid (self, cr);
 	}
 
 	if (self->priv->dragging) {
@@ -438,11 +441,11 @@ gth_image_rotator_expose (GthImageViewerTool *base,
 
 		center.x = self->priv->center.x * self->priv->preview_zoom + self->priv->preview_image_area.x;
 		center.y = self->priv->center.y * self->priv->preview_zoom + self->priv->preview_image_area.y;
-		paint_point (self, event, cr, &center);
+		paint_point (self, cr, &center);
 
 		/* used for debugging purposes
-		paint_point (self, event, cr, &self->priv->drag_p1);
-		paint_point (self, event, cr, &self->priv->drag_p2);
+		paint_point (self, cr, &self->priv->drag_p1);
+		paint_point (self, cr, &self->priv->drag_p2);
 		*/
 	}
 
@@ -465,7 +468,7 @@ gth_image_rotator_button_release (GthImageViewerTool *base,
 
 	cursor = gdk_cursor_new (GDK_LEFT_PTR);
 	gth_image_viewer_set_cursor (self->priv->viewer, cursor);
-	gdk_cursor_unref (cursor);
+	g_object_unref (cursor);
 
 	gtk_widget_queue_draw (GTK_WIDGET (self->priv->viewer));
 
@@ -544,7 +547,7 @@ gth_image_rotator_motion_notify (GthImageViewerTool *base,
 		cursor = gdk_cursor_new_from_name (gtk_widget_get_display (GTK_WIDGET (self->priv->viewer)), "grabbing");
 		gth_image_viewer_set_cursor (self->priv->viewer, cursor);
 		if (cursor != NULL)
-			gdk_cursor_unref (cursor);
+			g_object_unref (cursor);
 	}
 
 	if (self->priv->dragging) {
@@ -588,26 +591,6 @@ gth_image_rotator_zoom_changed (GthImageViewerTool *base)
 }
 
 
-static void
-gth_image_rotator_instance_init (GthImageRotator *self)
-{
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_IMAGE_ROTATOR, GthImageRotatorPrivate);
-	self->priv->preview_image = NULL;
-	self->priv->grid_type = GTH_GRID_NONE;
-	self->priv->resize = GTH_TRANSFORM_RESIZE_BOUNDING_BOX;
-	self->priv->background_color.r = 0.0;
-	self->priv->background_color.g = 0.0;
-	self->priv->background_color.b = 0.0;
-	self->priv->background_color.a = 1.0;
-	self->priv->enable_crop = FALSE;
-	self->priv->crop_region.x = 0;
-	self->priv->crop_region.y = 0;
-	self->priv->crop_region.width = 0;
-	self->priv->crop_region.height = 0;
-	self->priv->dragging = FALSE;
-}
-
-
 static void
 gth_image_rotator_finalize (GObject *object)
 {
@@ -621,7 +604,7 @@ gth_image_rotator_finalize (GObject *object)
 		cairo_surface_destroy (self->priv->preview_image);
 
 	/* Chain up */
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_image_rotator_parent_class)->finalize (object);
 }
 
 
@@ -630,7 +613,6 @@ gth_image_rotator_class_init (GthImageRotatorClass *class)
 {
 	GObjectClass *gobject_class;
 
-	parent_class = g_type_class_peek_parent (class);
 	g_type_class_add_private (class, sizeof (GthImageRotatorPrivate));
 
 	gobject_class = (GObjectClass*) class;
@@ -667,7 +649,7 @@ gth_image_rotator_class_init (GthImageRotatorClass *class)
 
 
 static void
-gth_image_rotator_gth_image_tool_interface_init (GthImageViewerToolIface *iface)
+gth_image_rotator_gth_image_tool_interface_init (GthImageViewerToolInterface *iface)
 {
 	iface->set_viewer = gth_image_rotator_set_viewer;
 	iface->unset_viewer = gth_image_rotator_unset_viewer;
@@ -676,7 +658,7 @@ gth_image_rotator_gth_image_tool_interface_init (GthImageViewerToolIface *iface)
 	iface->size_allocate = gth_image_rotator_size_allocate;
 	iface->map = gth_image_rotator_map;
 	iface->unmap = gth_image_rotator_unmap;
-	iface->expose = gth_image_rotator_expose;
+	iface->draw = gth_image_rotator_draw;
 	iface->button_press = gth_image_rotator_button_press;
 	iface->button_release = gth_image_rotator_button_release;
 	iface->motion_notify = gth_image_rotator_motion_notify;
@@ -685,37 +667,23 @@ gth_image_rotator_gth_image_tool_interface_init (GthImageViewerToolIface *iface)
 }
 
 
-GType
-gth_image_rotator_get_type (void)
+static void
+gth_image_rotator_init (GthImageRotator *self)
 {
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthImageRotatorClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_image_rotator_class_init,
-			NULL,
-			NULL,
-			sizeof (GthImageRotator),
-			0,
-			(GInstanceInitFunc) gth_image_rotator_instance_init
-		};
-		static const GInterfaceInfo gth_image_tool_info = {
-			(GInterfaceInitFunc) gth_image_rotator_gth_image_tool_interface_init,
-			(GInterfaceFinalizeFunc) NULL,
-			NULL
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-					       "GthImageRotator",
-					       &type_info,
-					       0);
-		g_type_add_interface_static (type, GTH_TYPE_IMAGE_VIEWER_TOOL, &gth_image_tool_info);
-	}
-
-	return type;
+	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_IMAGE_ROTATOR, GthImageRotatorPrivate);
+	self->priv->preview_image = NULL;
+	self->priv->grid_type = GTH_GRID_NONE;
+	self->priv->resize = GTH_TRANSFORM_RESIZE_BOUNDING_BOX;
+	self->priv->background_color.r = 0.0;
+	self->priv->background_color.g = 0.0;
+	self->priv->background_color.b = 0.0;
+	self->priv->background_color.a = 1.0;
+	self->priv->enable_crop = FALSE;
+	self->priv->crop_region.x = 0;
+	self->priv->crop_region.y = 0;
+	self->priv->crop_region.width = 0;
+	self->priv->crop_region.height = 0;
+	self->priv->dragging = FALSE;
 }
 
 
@@ -826,8 +794,8 @@ gth_image_rotator_get_resize (GthImageRotator *self)
 
 
 void
-gth_image_rotator_set_crop_region (GthImageRotator *self,
-				   GdkRectangle    *region)
+gth_image_rotator_set_crop_region (GthImageRotator       *self,
+				   cairo_rectangle_int_t *region)
 {
 	self->priv->enable_crop = (region != NULL);
 	if (region != NULL)
@@ -864,12 +832,12 @@ gth_image_rotator_get_background (GthImageRotator *self,
 static cairo_surface_t *
 gth_image_rotator_get_result_fast (GthImageRotator *self)
 {
-	double           tx, ty;
-	cairo_matrix_t   matrix;
-	GdkRectangle     image_area;
-	GdkRectangle     clip_area;
-	cairo_surface_t *output;
-	cairo_t         *cr;
+	double                 tx, ty;
+	cairo_matrix_t         matrix;
+	cairo_rectangle_int_t  image_area;
+	cairo_rectangle_int_t  clip_area;
+	cairo_surface_t       *output;
+	cairo_t               *cr;
 
 	/* compute the transformation matrix and the clip area */
 
