@@ -368,7 +368,7 @@ update_account_list (DialogData *data)
 	}
 	gtk_combo_box_set_active (GTK_COMBO_BOX (GET_WIDGET ("account_combobox")), current_account_idx);
 
-	free_space = g_format_size_for_display (data->user->max_bandwidth - data->user->used_bandwidth);
+	free_space = g_format_size (data->user->max_bandwidth - data->user->used_bandwidth);
 	gtk_label_set_text (GTK_LABEL (GET_WIDGET ("free_space_label")), free_space);
 	g_free (free_space);
 }
@@ -562,7 +562,7 @@ dlg_export_to_flickr (FlickrServer *server,
 		return;
 	}
 
-	total_size_formatted = g_format_size_for_display (total_size);
+	total_size_formatted = g_format_size (total_size);
 	text = g_strdup_printf (g_dngettext (NULL, "%d file (%s)", "%d files (%s)", n_total), n_total, total_size_formatted);
 	gtk_label_set_text (GTK_LABEL (GET_WIDGET ("images_info_label")), text);
 	g_free (text);
@@ -572,9 +572,8 @@ dlg_export_to_flickr (FlickrServer *server,
 
 	/* Set the widget data */
 
-	data->list_view = gth_file_list_new (gth_icon_view_new (), GTH_FILE_LIST_TYPE_NO_SELECTION, FALSE);
+	data->list_view = gth_file_list_new (gth_grid_view_new (), GTH_FILE_LIST_TYPE_NO_SELECTION, FALSE);
 	gth_file_list_set_thumb_size (GTH_FILE_LIST (data->list_view), 112);
-	gth_file_view_set_spacing (GTH_FILE_VIEW (gth_file_list_get_view (GTH_FILE_LIST (data->list_view))), 0);
 	gth_file_list_enable_thumbs (GTH_FILE_LIST (data->list_view), TRUE);
 	gth_file_list_set_ignore_hidden (GTH_FILE_LIST (data->list_view), TRUE);
 	gth_file_list_set_caption (GTH_FILE_LIST (data->list_view), "none");
