@@ -157,6 +157,8 @@ import_dialog_response_cb (GtkDialog *dialog,
 			file_list = get_files_to_download (data);
 			if (file_list != NULL) {
 				GFile               *destination;
+				GError              *error = NULL;
+				GSettings           *settings;
 				gboolean             single_subfolder;
 				GthSubfolderType     subfolder_type;
 				GthSubfolderFormat   subfolder_format;
@@ -166,10 +168,23 @@ import_dialog_response_cb (GtkDialog *dialog,
 				GthTask             *task;
 
 				destination = gth_import_preferences_get_destination ();
-				subfolder_type = eel_gconf_get_enum (PREF_IMPORT_SUBFOLDER_TYPE, GTH_TYPE_SUBFOLDER_TYPE, GTH_SUBFOLDER_TYPE_FILE_DATE);
-				subfolder_format = eel_gconf_get_enum (PREF_IMPORT_SUBFOLDER_FORMAT, GTH_TYPE_SUBFOLDER_FORMAT, GTH_SUBFOLDER_FORMAT_YYYYMMDD);
-				single_subfolder = eel_gconf_get_boolean (PREF_IMPORT_SUBFOLDER_SINGLE, FALSE);
-				custom_format = eel_gconf_get_string (PREF_IMPORT_SUBFOLDER_CUSTOM_FORMAT, "");
+
+				if (! gth_import_task_check_free_space (destination, file_list, &error)) {
+					_gtk_error_dialog_from_gerror_show (GTK_WINDOW (data->dialog),
+									    _("Could not import the files"),
+									    error);
+					g_clear_error (&error);
+					_g_object_unref (destination);
+					_g_object_list_unref (file_list);
+					g_object_unref (album);
+					return;
+				}
+
+				settings = g_settings_new (GTHUMB_IMPORTER_SCHEMA);
+				subfolder_type = g_settings_get_enum (settings, PREF_IMPORTER_SUBFOLDER_TYPE);
+				subfolder_format = g_settings_get_enum (settings, PREF_IMPORTER_SUBFOLDER_FORMAT);
+				single_subfolder = g_settings_get_boolean (settings, PREF_IMPORTER_SUBFOLDER_SINGLE);
+				custom_format = g_settings_get_string (settings, PREF_IMPORTER_SUBFOLDER_CUSTOM_FORMAT);
 
 				tags = g_strsplit ((album->keywords != NULL ? album->keywords : ""), ",", -1);
 				for (i = 0; tags[i] != NULL; i++)
@@ -192,6 +207,7 @@ import_dialog_response_cb (GtkDialog *dialog,
 
 				g_object_unref (task);
 				g_strfreev (tags);
+				g_object_unref (settings);
 				_g_object_unref (destination);
 			}
 
@@ -246,7 +262,7 @@ update_album_list (DialogData *data)
 		PicasaWebAlbum *album = scan->data;
 		char           *used_bytes;
 
-		used_bytes = g_format_size_for_display (album->used_bytes);
+		used_bytes = g_format_size (album->used_bytes);
 
 		gtk_list_store_append (GTK_LIST_STORE (GET_WIDGET ("album_liststore")), &iter);
 		gtk_list_store_set (GTK_LIST_STORE (GET_WIDGET ("album_liststore")), &iter,
@@ -291,7 +307,8 @@ list_albums_ready_cb (GObject      *source_object,
 	if (error != NULL) {
 		if (data->conn != NULL)
 			gth_task_dialog (GTH_TASK (data->conn), TRUE, NULL);
-		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (data->browser), _("Could not get the album list"), &error);
+		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (data->browser), _("Could not get the album list"), error);
+		g_clear_error (&error);
 		gtk_widget_destroy (data->dialog);
 		return;
 	}
@@ -360,7 +377,8 @@ connection_ready_cb (GObject      *source_object,
 		else {
 			if (data->conn != NULL)
 				gth_task_dialog (GTH_TASK (data->conn), TRUE, NULL);
-			_gtk_error_dialog_from_gerror_show (GTK_WINDOW (data->browser), _("Could not connect to the server"), &error);
+			_gtk_error_dialog_from_gerror_show (GTK_WINDOW (data->browser), _("Could not connect to the server"), error);
+			g_clear_error (&error);
 			gtk_widget_destroy (data->dialog);
 		}
 		return;
@@ -781,7 +799,7 @@ update_selection_status (DialogData *data)
 		size_selected += g_file_info_get_size (file_data->info);
 	}
 
-	size_selected_formatted = g_format_size_for_display (size_selected);
+	size_selected_formatted = g_format_size (size_selected);
 	text_selected = g_strdup_printf (g_dngettext (NULL, "%d file (%s)", "%d files (%s)", n_selected), n_selected, size_selected_formatted);
 	gtk_label_set_text (GTK_LABEL (GET_WIDGET ("images_info_label")), text_selected);
 
@@ -809,7 +827,8 @@ list_photos_ready_cb (GObject      *source_object,
 	if (error != NULL) {
 		if (data->conn != NULL)
 			gth_task_dialog (GTH_TASK (data->conn), TRUE, NULL);
-		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (data->browser), _("Could not get the photo list"), &error);
+		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (data->browser), _("Could not get the photo list"), error);
+		g_clear_error (&error);
 		gtk_widget_destroy (data->dialog);
 		return;
 	}
@@ -995,12 +1014,11 @@ dlg_import_from_picasaweb (GthBrowser *browser)
 
 	/* Set the widget data */
 
-	data->file_list = gth_file_list_new (gth_icon_view_new (), GTH_FILE_LIST_TYPE_NORMAL, FALSE);
+	data->file_list = gth_file_list_new (gth_grid_view_new (), GTH_FILE_LIST_TYPE_NORMAL, FALSE);
 	thumb_loader = gth_file_list_get_thumb_loader (GTH_FILE_LIST (data->file_list));
 	gth_thumb_loader_set_use_cache (thumb_loader, FALSE);
 	gth_thumb_loader_set_loader_func (thumb_loader, picasa_web_thumbnail_loader);
 	gth_file_list_set_thumb_size (GTH_FILE_LIST (data->file_list), PICASA_WEB_THUMB_SIZE_SMALL);
-	gth_file_view_set_spacing (GTH_FILE_VIEW (gth_file_list_get_view (GTH_FILE_LIST (data->file_list))), 0);
 	gth_file_list_enable_thumbs (GTH_FILE_LIST (data->file_list), TRUE);
 	gth_file_list_set_ignore_hidden (GTH_FILE_LIST (data->file_list), TRUE);
 	gth_file_list_set_caption (GTH_FILE_LIST (data->file_list), "none");
