@@ -118,6 +118,11 @@ gth_file_source_selections_write_metadata (GthFileSource *file_source,
 					   ReadyCallback  callback,
 					   gpointer       user_data)
 {
+	if (_g_file_attributes_matches_any (attributes, "sort::*"))
+		gth_selections_manager_set_sort_type (file_data->file,
+						      g_file_info_get_attribute_string (file_data->info, "sort::type"),
+						      g_file_info_get_attribute_boolean (file_data->info, "sort::inverse"));
+
 	object_ready_with_error (file_source, callback, user_data, NULL);
 }
 
@@ -129,6 +134,15 @@ gth_file_source_selections_read_metadata (GthFileSource *file_source,
 					  ReadyCallback  callback,
 					  gpointer       user_data)
 {
+	int n_selection;
+
+	n_selection = _g_file_get_n_selection (file_data->file);
+	if (n_selection < 0) {
+		GError *error = g_error_new_literal (G_IO_ERROR, G_IO_ERROR_NOT_FOUND, "Invalid location." /* FIXME: mark as translatable after string freeze */);
+		object_ready_with_error (file_source, callback, user_data, error);
+		return;
+	}
+
 	update_file_info (file_source, file_data->file, file_data->info);
 	object_ready_with_error (file_source, callback, user_data, NULL);
 }
