@@ -27,12 +27,12 @@
 #include "gth-selections-manager.h"
 
 
-#define N_SELECTIONS 3
-
-
 struct _GthSelectionsManagerPrivate {
-	GList  *files[N_SELECTIONS];
-	GMutex *mutex;
+	GList      *files[GTH_SELECTIONS_MANAGER_N_SELECTIONS];
+	GHashTable *files_hash[GTH_SELECTIONS_MANAGER_N_SELECTIONS];
+	char       *order[GTH_SELECTIONS_MANAGER_N_SELECTIONS];
+	gboolean    order_inverse[GTH_SELECTIONS_MANAGER_N_SELECTIONS];
+	GMutex     *mutex;
 };
 
 
@@ -70,8 +70,11 @@ gth_selections_manager_finalize (GObject *object)
 
 	self = GTH_SELECTIONS_MANAGER (object);
 
-	for (i = 0; i < N_SELECTIONS; i++)
+	for (i = 0; i < GTH_SELECTIONS_MANAGER_N_SELECTIONS; i++) {
 		_g_object_list_unref (self->priv->files[i]);
+		g_hash_table_unref (self->priv->files_hash[i]);
+		g_free (self->priv->order[i]);
+	}
 	g_mutex_free (self->priv->mutex);
 
 	G_OBJECT_CLASS (gth_selections_manager_parent_class)->finalize (object);
@@ -97,8 +100,12 @@ gth_selections_manager_init (GthSelectionsManager *self)
 
 	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_SELECTIONS_MANAGER, GthSelectionsManagerPrivate);
 	self->priv->mutex = g_mutex_new ();
-	for (i = 0; i < N_SELECTIONS; i++)
+	for (i = 0; i < GTH_SELECTIONS_MANAGER_N_SELECTIONS; i++) {
 		self->priv->files[i] = NULL;
+		self->priv->files_hash[i] = g_hash_table_new (g_file_hash, (GEqualFunc) g_file_equal);
+		self->priv->order[i] = NULL;
+		self->priv->order_inverse[i] = FALSE;
+	}
 }
 
 
@@ -187,26 +194,6 @@ selections_manager_fec_done_cb (GObject  *object,
 }
 
 
-static int
-_g_file_get_n_selection (GFile *file)
-{
-	char *uri;
-	int   n = -1;
-
-	uri = g_file_get_uri (file);
-	if (! g_str_has_prefix (uri, "selection:///"))
-		n = -1;
-	else if (strcmp (uri, "selection:///") == 0)
-		n = 0;
-	else
-		n = atoi (uri + strlen ("selection:///"));
-
-	g_free (uri);
-
-	return n;
-}
-
-
 void
 gth_selections_manager_update_file_info (GFile     *file,
 					 GFileInfo *info)
@@ -221,6 +208,8 @@ gth_selections_manager_update_file_info (GFile     *file,
 
 	g_file_info_set_sort_order (info, n_selection);
 	g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_READ, TRUE);
+	if (n_selection > 0)
+		g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE, TRUE);
 	g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_DELETE, FALSE);
 	g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_RENAME, FALSE);
 	g_file_info_set_attribute_int32 (info, "gthumb::n-selection", n_selection);
@@ -255,6 +244,33 @@ gth_selections_manager_update_file_info (GFile     *file,
 		name = g_strdup ("???");
 	g_file_info_set_display_name (info, name);
 	g_free (name);
+
+	/* name */
+
+	if (n_selection > 0)
+		name = g_strdup_printf ("%d", n_selection);
+	else
+		name = g_strdup ("");
+	g_file_info_set_name (info, name);
+
+	g_free (name);
+
+	/* sort order */
+
+	if (n_selection > 0) {
+		GthSelectionsManager *self;
+
+		self = gth_selections_manager_get_default ();
+
+		if (self->priv->order[n_selection] != NULL) {
+			g_file_info_set_attribute_string (info, "sort::type", self->priv->order[n_selection - 1]);
+			g_file_info_set_attribute_boolean (info, "sort::inverse", self->priv->order_inverse[n_selection - 1]);
+		}
+		else {
+			g_file_info_remove_attribute (info, "sort::type");
+			g_file_info_remove_attribute (info, "sort::inverse");
+		}
+	}
 }
 
 
@@ -264,7 +280,7 @@ _gth_selections_manager_for_each_selection (gpointer user_data)
 	ForEachChildData *data = user_data;
 	int               i;
 
-	for (i = 0; i < N_SELECTIONS; i++) {
+	for (i = 0; i < GTH_SELECTIONS_MANAGER_N_SELECTIONS; i++) {
 		char      *uri;
 		GFile     *file;
 		GFileInfo *info;
@@ -340,6 +356,7 @@ gth_selections_manager_add_files (GFile *folder,
 	GthSelectionsManager *self;
 	int                   n_selection;
 	GList                *new_list;
+	GList                *scan;
 	GList                *link;
 
 	if (! g_file_has_uri_scheme (folder, "selection"))
@@ -353,6 +370,10 @@ gth_selections_manager_add_files (GFile *folder,
 	g_mutex_lock (self->priv->mutex);
 
 	new_list = _g_file_list_dup (file_list);
+
+	for (scan = new_list; scan; scan = scan->next)
+		g_hash_table_insert (self->priv->files_hash[n_selection - 1], scan->data, GINT_TO_POINTER (1));
+
 	link = g_list_nth (self->priv->files[n_selection - 1], destination_position);
 	if (link != NULL) {
 		GList *last_new;
@@ -370,6 +391,7 @@ gth_selections_manager_add_files (GFile *folder,
 	else
 		self->priv->files[n_selection - 1] = g_list_concat (self->priv->files[n_selection - 1], new_list);
 
+	gth_monitor_emblems_changed (gth_main_get_default_monitor (), file_list);
 	gth_monitor_folder_changed (gth_main_get_default_monitor (),
 				    folder,
 				    file_list,
@@ -399,8 +421,10 @@ gth_selections_manager_remove_files (GFile *folder,
 	g_mutex_lock (self->priv->mutex);
 
 	files_to_remove = g_hash_table_new (g_file_hash, (GEqualFunc) g_file_equal);
-	for (scan = file_list; scan; scan = scan->next)
+	for (scan = file_list; scan; scan = scan->next) {
 		g_hash_table_insert (files_to_remove, scan->data, GINT_TO_POINTER (1));
+		g_hash_table_remove (self->priv->files_hash[n_selection - 1], scan->data);
+	}
 
 	new_list = NULL;
 	for (scan = self->priv->files[n_selection - 1]; scan; scan = scan->next) {
@@ -422,6 +446,7 @@ gth_selections_manager_remove_files (GFile *folder,
 				    folder,
 				    file_list,
 				    GTH_MONITOR_EVENT_REMOVED);
+	gth_monitor_emblems_changed (gth_main_get_default_monitor (), file_list);
 
 	g_mutex_unlock (self->priv->mutex);
 }
@@ -433,5 +458,102 @@ gth_selections_manager_reorder (GFile *folder,
 				GList *files_to_move, /* GFile list */
 				int    dest_pos)
 {
-	/* FIXME */
+	GthSelectionsManager *self;
+	int                   n_selection;
+	int                  *new_order;
+	GList                *new_file_list;
+
+	n_selection = _g_file_get_n_selection (folder);
+	if (n_selection <= 0)
+		return;
+
+	self = gth_selections_manager_get_default ();
+
+	/* reorder the file list */
+
+	g_mutex_lock (self->priv->mutex);
+	_g_list_reorder (self->priv->files[n_selection - 1],
+			 visible_files,
+			 files_to_move,
+			 dest_pos,
+			 &new_order,
+			 &new_file_list);
+	_g_object_list_unref (self->priv->files[n_selection - 1]);
+	self->priv->files[n_selection - 1] = new_file_list;
+	g_mutex_unlock (self->priv->mutex);
+
+	gth_selections_manager_set_sort_type (folder, "general::unsorted", FALSE);
+
+	gth_monitor_order_changed (gth_main_get_default_monitor (),
+				   folder,
+				   new_order);
+
+	g_free (new_order);
+}
+
+
+void
+gth_selections_manager_set_sort_type (GFile      *folder,
+				      const char *sort_type,
+				      gboolean    sort_inverse)
+{
+	GthSelectionsManager *self;
+	int                   n_selection;
+
+	n_selection = _g_file_get_n_selection (folder);
+	if (n_selection <= 0)
+		return;
+
+	self = gth_selections_manager_get_default ();
+	g_mutex_lock (self->priv->mutex);
+
+	g_free (self->priv->order[n_selection - 1]);
+	self->priv->order[n_selection - 1] = g_strdup (sort_type);
+	self->priv->order_inverse[n_selection - 1] = sort_inverse;
+
+	g_mutex_unlock (self->priv->mutex);
+}
+
+
+gboolean
+gth_selections_manager_file_exists (int    n_selection,
+				    GFile *file)
+{
+	GthSelectionsManager *self;
+	gboolean             result;
+
+	if ((n_selection <= 0) || (n_selection > GTH_SELECTIONS_MANAGER_N_SELECTIONS))
+		return FALSE;
+
+	self = gth_selections_manager_get_default ();
+	g_mutex_lock (self->priv->mutex);
+
+	result = (g_hash_table_lookup (self->priv->files_hash[n_selection - 1], file) != NULL);
+
+	g_mutex_unlock (self->priv->mutex);
+
+	return result;
+}
+
+
+int
+_g_file_get_n_selection (GFile *file)
+{
+	char *uri;
+	int   n = -1;
+
+	uri = g_file_get_uri (file);
+	if (! g_str_has_prefix (uri, "selection:///"))
+		n = -1;
+	else if (strcmp (uri, "selection:///") == 0)
+		n = 0;
+	else
+		n = atoi (uri + strlen ("selection:///"));
+
+	g_free (uri);
+
+	if (n > GTH_SELECTIONS_MANAGER_N_SELECTIONS)
+		n = -1;
+
+	return n;
 }
