@@ -56,6 +56,18 @@ _cairo_multiply_alpha (int color,
 }
 
 
+gboolean
+_cairo_rectangle_contains_point (cairo_rectangle_int_t *rect,
+			 	 int                    x,
+			 	 int                    y)
+{
+	return ((x >= rect->x)
+		&& (y >= rect->y)
+		&& (x <= rect->x + rect->width)
+		&& (y <= rect->y + rect->height));
+}
+
+
 void
 _gdk_color_to_cairo_color (GdkColor      *g_color,
 			   cairo_color_t *c_color)
@@ -591,17 +603,6 @@ _cairo_draw_rounded_box (cairo_t *cr,
 	if (r == 0) {
 		cairo_rectangle (cr, x, y, w, h);
 	}
-	else if (r == 1) {
-		cairo_move_to (cr, x + 1, y);
-		cairo_rel_line_to (cr, w - 2, 0);
-		cairo_rel_line_to (cr, 1, 1);
-		cairo_rel_line_to (cr, 0, h - 2);
-		cairo_rel_line_to (cr, -1, 1);
-		cairo_rel_line_to (cr, - (w - 2), 0);
-		cairo_rel_line_to (cr, -1, -1);
-		cairo_rel_line_to (cr, 0, - (h - 2));
-		cairo_rel_line_to (cr, 1, -1);
-	}
 	else {
 		cairo_move_to (cr, x, y + r);
 		if (r > 0)
@@ -782,9 +783,9 @@ _cairo_draw_slide (cairo_t  *cr,
 
 
 void
-_cairo_paint_grid (cairo_t      *cr,
-		   GdkRectangle *rectangle,
-		   GthGridType   grid_type)
+_cairo_paint_grid (cairo_t               *cr,
+		   cairo_rectangle_int_t *rectangle,
+		   GthGridType            grid_type)
 {
 	double ux, uy;
 
