@@ -21,7 +21,6 @@
 
 #include <config.h>
 #include <gtk/gtk.h>
-#include "gconf-utils.h"
 #include "glib-utils.h"
 #include "gth-browser.h"
 #include "gth-main.h"
@@ -31,7 +30,7 @@
 
 
 #define GET_WIDGET(name) _gtk_builder_get_widget (data->builder, (name))
-#define DEFAULT_ICON "application-x-executable"
+#define DEFAULT_ICON "application-extension"
 #define EXTENSION_CATEGORY_ALL "*"
 #define EXTENSION_CATEGORY_ENABLED "+"
 #define EXTENSION_CATEGORY_DISABLED "-"
@@ -83,11 +82,12 @@ static ExtensionCategory extension_category[] = {
 typedef struct {
 	GthBrowser   *browser;
 	GtkBuilder   *builder;
+	GSettings    *settings;
 	GtkWidget    *dialog;
 	GtkWidget    *list_view;
 	GtkListStore *list_store;
 	GtkTreeModel *model_filter;
-	GSList       *active_extensions;
+	GList        *active_extensions;
 	char         *current_category;
 	gboolean      enabled_disabled_cardinality_changed;
 } BrowserData;
@@ -97,8 +97,9 @@ typedef struct {
 static void
 browser_data_free (BrowserData *data)
 {
-	g_slist_foreach (data->active_extensions, (GFunc) g_free, NULL);
-	g_slist_free (data->active_extensions);
+	g_list_foreach (data->active_extensions, (GFunc) g_free, NULL);
+	g_list_free (data->active_extensions);
+	g_object_unref (data->settings);
 	g_object_unref (data->builder);
 	g_free (data->current_category);
 	g_free (data);
@@ -106,17 +107,17 @@ browser_data_free (BrowserData *data)
 
 
 static gboolean
-list_equal (GSList *list1,
-	    GSList *list2)
+list_equal (GList *list1,
+	    GList *list2)
 {
-	GSList *sscan1;
+	GList *sscan1;
 
-	if (g_slist_length (list1) != g_slist_length (list2))
+	if (g_list_length (list1) != g_list_length (list2))
 		return FALSE;
 
 	for (sscan1 = list1; sscan1; sscan1 = sscan1->next) {
-		char   *name1 = sscan1->data;
-		GSList *sscan2;
+		char  *name1 = sscan1->data;
+		GList *sscan2;
 
 		for (sscan2 = list2; sscan2; sscan2 = sscan2->next) {
 			char *name2 = sscan2->data;
@@ -143,7 +144,7 @@ extension_description_data_func_cb (GtkTreeViewColumn *tree_column,
 	GthExtensionDescription *description;
 	char                    *text;
 
-	gtk_tree_model_get (tree_model, iter, 0, &description, -1);
+	gtk_tree_model_get (tree_model, iter, EXTENSION_DESCRIPTION_COLUMN, &description, -1);
 
 	text = g_markup_printf_escaped ("<b>%s</b>\n<small>%s</small>", description->name, description->description);
 	g_object_set (G_OBJECT (cell), "markup", text, NULL);
@@ -163,7 +164,7 @@ extension_icon_data_func_cb (GtkTreeViewColumn *tree_column,
 {
 	GthExtensionDescription *description;
 
-	gtk_tree_model_get (tree_model, iter, 0, &description, -1);
+	gtk_tree_model_get (tree_model, iter, EXTENSION_DESCRIPTION_COLUMN, &description, -1);
 	if (description->icon_name != NULL)
 		g_object_set (G_OBJECT (cell), "icon-name", description->icon_name, NULL);
 	else
@@ -183,7 +184,7 @@ extension_active_data_func_cb (GtkTreeViewColumn *tree_column,
 {
 	GthExtensionDescription *description;
 
-	gtk_tree_model_get (tree_model, iter, 0, &description, -1);
+	gtk_tree_model_get (tree_model, iter, EXTENSION_DESCRIPTION_COLUMN, &description, -1);
 	g_object_set (G_OBJECT (cell), "active", gth_extension_description_is_active (description), NULL);
 
 	g_object_unref (description);
@@ -208,7 +209,7 @@ cell_renderer_toggle_toggled_cb (GtkCellRendererToggle *cell_renderer,
 		GError                  *error = NULL;
 		GtkTreeIter              child_iter;
 
-		gtk_tree_model_get (GTK_TREE_MODEL (data->model_filter), &iter, 0, &description, -1);
+		gtk_tree_model_get (GTK_TREE_MODEL (data->model_filter), &iter, EXTENSION_DESCRIPTION_COLUMN, &description, -1);
 		gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER (data->model_filter), &child_iter, &iter);
 		if (! gth_extension_description_is_active (description)) {
 			if (! gth_extension_manager_activate (gth_main_get_default_extension_manager (), description->id, &error)) {
@@ -216,7 +217,7 @@ cell_renderer_toggle_toggled_cb (GtkCellRendererToggle *cell_renderer,
 				g_clear_error (&error);
 			}
 			else {
-				gtk_list_store_set (data->list_store, &child_iter, 0, description, -1);
+				gtk_list_store_set (data->list_store, &child_iter, EXTENSION_DESCRIPTION_COLUMN, description, -1);
 				data->enabled_disabled_cardinality_changed = TRUE;
 			}
 		}
@@ -226,7 +227,7 @@ cell_renderer_toggle_toggled_cb (GtkCellRendererToggle *cell_renderer,
 				g_clear_error (&error);
 			}
 			else {
-				gtk_list_store_set (data->list_store, &child_iter, 0, description, -1);
+				gtk_list_store_set (data->list_store, &child_iter, EXTENSION_DESCRIPTION_COLUMN, description, -1);
 				data->enabled_disabled_cardinality_changed = TRUE;
 			}
 		}
@@ -266,7 +267,7 @@ add_columns (GtkTreeView *treeview,
 
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	gtk_tree_view_column_pack_start (column, renderer, FALSE);
-	g_object_set (renderer, "stock-size", GTK_ICON_SIZE_BUTTON, NULL);
+	g_object_set (renderer, "stock-size", GTK_ICON_SIZE_BUTTON, "xpad", 6, NULL);
 	gtk_tree_view_column_set_cell_data_func (column, renderer, extension_icon_data_func_cb, data, NULL);
 
 	renderer = gtk_cell_renderer_text_new ();
@@ -316,8 +317,8 @@ extension_compare_func (GtkTreeModel *tree_model,
 	GthExtensionDescription *description_b;
 	int                      result;
 
-	gtk_tree_model_get (tree_model, iter_a, 0, &description_a, -1);
-	gtk_tree_model_get (tree_model, iter_b, 0, &description_b, -1);
+	gtk_tree_model_get (tree_model, iter_a, EXTENSION_DESCRIPTION_COLUMN, &description_a, -1);
+	gtk_tree_model_get (tree_model, iter_b, EXTENSION_DESCRIPTION_COLUMN, &description_b, -1);
 
 	result = strcmp (description_a->name, description_b->name);
 
@@ -529,7 +530,7 @@ about_button_clicked_cb (GtkButton *button,
 	if (! gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW (data->list_view)), &model, &iter))
 		return;
 
-	gtk_tree_model_get (model, &iter, 0, &description, -1);
+	gtk_tree_model_get (model, &iter, EXTENSION_DESCRIPTION_COLUMN, &description, -1);
 
 	dialog = gtk_about_dialog_new ();
 	if (description->name != NULL)
@@ -571,7 +572,7 @@ preferences_button_clicked_cb (GtkButton *button,
 	if (! gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW (data->list_view)), &model, &iter))
 		return;
 
-	gtk_tree_model_get (model, &iter, 0, &description, -1);
+	gtk_tree_model_get (model, &iter, EXTENSION_DESCRIPTION_COLUMN, &description, -1);
 	extension = gth_extension_description_get_extension (description);
 	gth_extension_configure (extension, GTK_WINDOW (data->dialog));
 
@@ -626,20 +627,20 @@ extensions__dlg_preferences_construct_cb (GtkWidget  *dialog,
 					  GthBrowser *browser,
 					  GtkBuilder *dialog_builder)
 {
-	BrowserData         *data;
-	GtkWidget           *notebook;
-	GtkWidget           *page;
-	GthExtensionManager *manager;
-	GList               *extensions;
-	GList               *scan;
-	GSList              *all_active_extensions;
-	GSList              *s_scan;
-	GtkTreePath         *first;
-	int                  i;
-	GtkWidget           *label;
+	BrowserData          *data;
+	GtkWidget            *notebook;
+	GtkWidget            *page;
+	GthExtensionManager  *manager;
+	GList                *extensions;
+	GList                *scan;
+	char                **all_active_extensions;
+	int                   i;
+	GtkTreePath          *first;
+	GtkWidget            *label;
 
 	data = g_new0 (BrowserData, 1);
 	data->builder = _gtk_builder_new_from_file ("extensions-preferences.ui", NULL);
+	data->settings = g_settings_new (GTHUMB_GENERAL_SCHEMA);
 	data->dialog = dialog;
 	data->enabled_disabled_cardinality_changed = FALSE;
 
@@ -647,20 +648,19 @@ extensions__dlg_preferences_construct_cb (GtkWidget  *dialog,
 
 	manager = gth_main_get_default_extension_manager ();
 	data->active_extensions = NULL;
-	all_active_extensions = eel_gconf_get_string_list (PREF_ACTIVE_EXTENSIONS);
-	for (s_scan = all_active_extensions; s_scan; s_scan = s_scan->next) {
-		char                    *name = s_scan->data;
+	all_active_extensions = g_settings_get_strv (data->settings, PREF_GENERAL_ACTIVE_EXTENSIONS);
+	for (i = 0; all_active_extensions[i] != NULL; i++) {
+		char                    *name = all_active_extensions[i];
 		GthExtensionDescription *description;
 
 		description = gth_extension_manager_get_description (manager, name);
 		if ((description == NULL) || description->mandatory || description->hidden)
 			continue;
 
-		data->active_extensions = g_slist_prepend (data->active_extensions, g_strdup (name));
+		data->active_extensions = g_list_prepend (data->active_extensions, g_strdup (name));
 	}
-	data->active_extensions = g_slist_reverse (data->active_extensions);
-	g_slist_foreach (all_active_extensions, (GFunc) g_free, NULL);
-	g_slist_free (all_active_extensions);
+	data->active_extensions = g_list_reverse (data->active_extensions);
+	g_strfreev (all_active_extensions);
 
 	notebook = _gtk_builder_get_widget (dialog_builder, "notebook");
 	page = _gtk_builder_get_widget (data->builder, "preferences_page");
@@ -784,9 +784,9 @@ extensions__dlg_preferences_apply (GtkWidget  *dialog,
 		  	  	   GtkBuilder *dialog_builder)
 {
 	BrowserData         *data;
-	GSList              *active_extensions;
+	GList               *active_extensions;
 	GthExtensionManager *manager;
-	GList               *names;
+	GList               *extension_names;
 	GList               *scan;
 
 	data = g_object_get_data (G_OBJECT (dialog), BROWSER_DATA_KEY);
@@ -794,20 +794,20 @@ extensions__dlg_preferences_apply (GtkWidget  *dialog,
 
 	active_extensions = NULL;
 	manager = gth_main_get_default_extension_manager ();
-	names = gth_extension_manager_get_extensions (manager);
-	for (scan = names; scan; scan = scan->next) {
-		char                    *name = scan->data;
+	extension_names = gth_extension_manager_get_extensions (manager);
+	for (scan = extension_names; scan; scan = scan->next) {
+		char                    *extension_name = scan->data;
 		GthExtensionDescription *description;
 
-		description = gth_extension_manager_get_description (manager, name);
+		description = gth_extension_manager_get_description (manager, extension_name);
 		if ((description == NULL) || description->mandatory || description->hidden)
 			continue;
 
 		if (gth_extension_description_is_active (description))
-			active_extensions = g_slist_prepend (active_extensions, g_strdup (name));
+			active_extensions = g_list_prepend (active_extensions, g_strdup (extension_name));
 	}
-	active_extensions = g_slist_reverse (active_extensions);
-	eel_gconf_set_string_list (PREF_ACTIVE_EXTENSIONS, active_extensions);
+	active_extensions = g_list_reverse (active_extensions);
+	_g_settings_set_string_list (data->settings, PREF_GENERAL_ACTIVE_EXTENSIONS, active_extensions);
 
 	if (! list_equal (active_extensions, data->active_extensions)) {
 		GtkWidget *dialog;
@@ -828,6 +828,7 @@ extensions__dlg_preferences_apply (GtkWidget  *dialog,
 			gth_quit (TRUE);
 	}
 
-	g_slist_foreach (active_extensions, (GFunc) g_free, NULL);
-	g_slist_free (active_extensions);
+	g_list_foreach (active_extensions, (GFunc) g_free, NULL);
+	g_list_free (active_extensions);
+	g_list_free (extension_names);
 }
