@@ -55,6 +55,7 @@ G_BEGIN_DECLS
 #define GFILE_STANDARD_ATTRIBUTES_WITH_FAST_CONTENT_TYPE (DEFINE_STANDARD_ATTRIBUTES(",standard::fast-content-type"))
 #define GFILE_STANDARD_ATTRIBUTES_WITH_CONTENT_TYPE (DEFINE_STANDARD_ATTRIBUTES(",standard::fast-content-type,standard::content-type"))
 #define GIO_ATTRIBUTES ("standard::*,etag::*,id::*,access::*,mountable::*,time::*,unix::*,dos::*,owner::*,thumbnail::*,filesystem::*,gvfs::*,xattr::*,xattr-sys::*,selinux::*")
+#define GTH_FILE_ATTRIBUTE_EMBLEMS "gth::file::emblems"
 
 #define GNOME_COPIED_FILES (gdk_atom_intern_static_string ("x-special/gnome-copied-files"))
 #define IROUND(x) ((int)floor(((double)x) + 0.5))
@@ -184,6 +185,12 @@ char *          _g_utf8_remove_extension         (const char  *str);
 GList *         _g_list_insert_list_before       (GList       *list1,
 						  GList       *sibling,
 						  GList       *list2);
+void            _g_list_reorder                  (GList       *all_files,
+						  GList       *visible_files,
+						  GList       *files_to_move,
+						  int          dest_pos,
+						  int        **new_order_p,
+						  GList      **new_file_list_p);
 const char *    get_static_string                (const char  *s);
 char *          _g_rand_string                   (int          len);
 int             _g_strv_find                     (char       **v,
