@@ -36,10 +36,10 @@
 
 
 typedef struct {
-	int           ref_count;
-	int           id;
-	GdkRectangle  area;
-	GdkCursor    *cursor;
+	int                    ref_count;
+	int                    id;
+	cairo_rectangle_int_t  area;
+	GdkCursor             *cursor;
 } EventArea;
 
 
@@ -80,7 +80,7 @@ event_area_unref (EventArea *event_area)
 		return;
 
 	if (event_area->cursor != NULL)
-		gdk_cursor_unref (event_area->cursor);
+		g_object_unref (event_area->cursor);
 	g_free (event_area);
 }
 
@@ -186,46 +186,55 @@ enum {
 
 
 static guint signals[LAST_SIGNAL] = { 0 };
-static gpointer parent_class = NULL;
 
 
 struct _GthImageSelectorPrivate {
-	GthImageViewer  *viewer;
-	GthSelectorType  type;
+	GthImageViewer         *viewer;
+	GthSelectorType         type;
 
-	cairo_surface_t *surface;
-	GdkRectangle     surface_area;
+	cairo_surface_t        *surface;
+	cairo_rectangle_int_t   surface_area;
 
-	gboolean         use_ratio;
-	double           ratio;
-	gboolean         mask_visible;
-	GthGridType      grid_type;
-	gboolean         active;
-	gboolean         bind_dimensions;
-	int              bind_factor;
+	gboolean                use_ratio;
+	double                  ratio;
+	gboolean                mask_visible;
+	GthGridType             grid_type;
+	gboolean                active;
+	gboolean                bind_dimensions;
+	int                     bind_factor;
 
-	GdkRectangle     drag_start_selection_area;
-	GdkRectangle     selection_area;
-	GdkRectangle     selection;
+	cairo_rectangle_int_t   drag_start_selection_area;
+	cairo_rectangle_int_t   selection_area;
+	cairo_rectangle_int_t   selection;
 
-	GdkCursor       *default_cursor;
-	GdkCursor       *current_cursor;
-	GList           *event_list;
-	EventArea       *current_area;
+	GdkCursor              *default_cursor;
+	GdkCursor              *current_cursor;
+	GList                  *event_list;
+	EventArea              *current_area;
 
-	guint            timer_id; 	    /* Timeout ID for
-					     * autoscrolling */
-	double           x_value_diff;      /* Change the adjustment value
-					     * by this
-					     * amount when autoscrolling */
-	double           y_value_diff;
+	guint                   timer_id; 	    /* Timeout ID for
+	 	 	 	 	 	     * autoscrolling */
+	double                  x_value_diff;       /* Change the adjustment value
+	 	 	 	 	 	     * by this
+	 	 	 	 	 	     * amount when autoscrolling */
+	double                  y_value_diff;
 };
 
 
+static void gth_image_selector_gth_image_tool_interface_init (GthImageViewerToolInterface *iface);
+
+
+G_DEFINE_TYPE_WITH_CODE (GthImageSelector,
+			 gth_image_selector,
+			 G_TYPE_OBJECT,
+			 G_IMPLEMENT_INTERFACE (GTH_TYPE_IMAGE_VIEWER_TOOL,
+					 	gth_image_selector_gth_image_tool_interface_init))
+
+
 static gboolean
-point_in_rectangle (int          x,
-		    int          y,
-		    GdkRectangle rect)
+point_in_rectangle (int                   x,
+		    int                   y,
+		    cairo_rectangle_int_t rect)
 {
 	return ((x >= rect.x)
 		&& (x <= rect.x + rect.width)
@@ -235,8 +244,8 @@ point_in_rectangle (int          x,
 
 
 static gboolean
-rectangle_in_rectangle (GdkRectangle r1,
-			GdkRectangle r2)
+rectangle_in_rectangle (cairo_rectangle_int_t r1,
+			cairo_rectangle_int_t r2)
 {
 	return (point_in_rectangle (r1.x, r1.y, r2)
 		&& point_in_rectangle (r1.x + r1.width,
@@ -246,8 +255,8 @@ rectangle_in_rectangle (GdkRectangle r1,
 
 
 static gboolean
-rectangle_equal (GdkRectangle r1,
-		 GdkRectangle r2)
+rectangle_equal (cairo_rectangle_int_t r1,
+		 cairo_rectangle_int_t r2)
 {
 	return ((r1.x == r2.x)
 		&& (r1.y == r2.y)
@@ -265,9 +274,9 @@ real_to_selector (GthImageSelector *self,
 
 
 static void
-convert_to_selection_area (GthImageSelector *self,
-			   GdkRectangle      real_area,
-			   GdkRectangle     *selection_area)
+convert_to_selection_area (GthImageSelector      *self,
+			   cairo_rectangle_int_t  real_area,
+			   cairo_rectangle_int_t *selection_area)
 {
 	selection_area->x = real_to_selector (self, real_area.x);
 	selection_area->y = real_to_selector (self, real_area.y);
@@ -307,8 +316,8 @@ get_event_area_from_position (GthImageSelector *self,
 	GList *scan;
 
 	for (scan = self->priv->event_list; scan; scan = scan->next) {
-		EventArea    *event_area = scan->data;
-		GdkRectangle  widget_area;
+		EventArea             *event_area = scan->data;
+		cairo_rectangle_int_t  widget_area;
 
 		widget_area = event_area->area;
 		widget_area.x += self->priv->viewer->image_area.x;
@@ -424,8 +433,8 @@ update_event_areas (GthImageSelector *self)
 
 
 static void
-queue_draw (GthImageSelector *self,
-	    GdkRectangle      area)
+queue_draw (GthImageSelector      *self,
+	    cairo_rectangle_int_t  area)
 {
 	if (! gtk_widget_get_realized (GTK_WIDGET (self->priv->viewer)))
 		return;
@@ -447,12 +456,12 @@ selection_changed (GthImageSelector *self)
 
 
 static void
-set_selection_area (GthImageSelector *self,
-		    GdkRectangle      new_selection,
-		    gboolean          force_update)
+set_selection_area (GthImageSelector      *self,
+		    cairo_rectangle_int_t  new_selection,
+		    gboolean               force_update)
 {
-	GdkRectangle old_selection_area;
-	GdkRectangle dirty_region;
+	cairo_rectangle_int_t old_selection_area;
+	cairo_rectangle_int_t dirty_region;
 
 	if (! force_update && rectangle_equal (self->priv->selection_area, new_selection))
 		return;
@@ -467,11 +476,11 @@ set_selection_area (GthImageSelector *self,
 
 
 static void
-set_selection (GthImageSelector *self,
-	       GdkRectangle      new_selection,
-	       gboolean          force_update)
+set_selection (GthImageSelector      *self,
+	       cairo_rectangle_int_t  new_selection,
+	       gboolean               force_update)
 {
-	GdkRectangle new_area;
+	cairo_rectangle_int_t new_area;
 
 	if (! force_update && rectangle_equal (self->priv->selection, new_selection))
 		return;
@@ -485,7 +494,7 @@ set_selection (GthImageSelector *self,
 static void
 init_selection (GthImageSelector *self)
 {
-	GdkRectangle area;
+	cairo_rectangle_int_t area;
 
 	/*
 	if (! self->priv->use_ratio) {
@@ -564,7 +573,7 @@ gth_image_selector_unrealize (GthImageViewerTool *base)
 	GthImageSelector *self = GTH_IMAGE_SELECTOR (base);
 
 	if (self->priv->default_cursor != NULL) {
-		gdk_cursor_unref (self->priv->default_cursor);
+		g_object_unref (self->priv->default_cursor);
 		self->priv->default_cursor = NULL;
 	}
 
@@ -599,7 +608,6 @@ gth_image_selector_unmap (GthImageViewerTool *base)
 
 static void
 paint_background (GthImageSelector *self,
-		  GdkEventExpose   *event,
 		  cairo_t          *cr)
 {
 	gth_image_viewer_paint_region (self->priv->viewer,
@@ -608,38 +616,24 @@ paint_background (GthImageSelector *self,
 				       self->priv->viewer->x_offset - self->priv->viewer->image_area.x,
 				       self->priv->viewer->y_offset - self->priv->viewer->image_area.y,
 				       &self->priv->viewer->image_area,
-				       event->region,
+				       NULL,
 				       gth_image_viewer_get_zoom_quality_filter (self->priv->viewer));
 
 	/* make the background darker */
-	{
-		GdkRectangle *rects;
-		int           n_rects;
-		int           i;
 
-		gdk_cairo_rectangle (cr, &self->priv->viewer->image_area);
-		cairo_clip (cr);
-		cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.5);
-		gdk_region_get_rectangles (event->region, &rects, &n_rects);
-		for (i = 0; i < n_rects; i++) {
-			GdkRectangle paint_area;
-
-			if (gdk_rectangle_intersect (&self->priv->viewer->image_area, &rects[i], &paint_area))
-				cairo_rectangle (cr, paint_area.x, paint_area.y, paint_area.width, paint_area.height);
-		}
-		cairo_fill (cr);
-
-		g_free (rects);
-	}
+	cairo_save (cr);
+	gdk_cairo_rectangle (cr, &self->priv->viewer->image_area);
+	cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.5);
+	cairo_fill (cr);
+	cairo_restore (cr);
 }
 
 
 static void
 paint_selection (GthImageSelector *self,
-		 GdkEventExpose   *event,
 		 cairo_t          *cr)
 {
-	GdkRectangle selection_area;
+	cairo_rectangle_int_t selection_area;
 
 	selection_area = self->priv->selection_area;
 	selection_area.x += self->priv->viewer->image_area.x - self->priv->viewer->x_offset;
@@ -652,7 +646,7 @@ paint_selection (GthImageSelector *self,
 					       self->priv->viewer->x_offset - self->priv->viewer->image_area.x,
 					       self->priv->viewer->y_offset - self->priv->viewer->image_area.y,
 					       &selection_area,
-					       event->region,
+					       NULL,
 					       gth_image_viewer_get_zoom_quality_filter (self->priv->viewer));
 
 	cairo_save (cr);
@@ -685,7 +679,6 @@ paint_selection (GthImageSelector *self,
 
 static void
 paint_image (GthImageSelector *self,
-	     GdkEventExpose   *event,
 	     cairo_t          *cr)
 {
 	gth_image_viewer_paint_region (self->priv->viewer,
@@ -694,15 +687,14 @@ paint_image (GthImageSelector *self,
 				       self->priv->viewer->x_offset - self->priv->viewer->image_area.x,
 				       self->priv->viewer->y_offset - self->priv->viewer->image_area.y,
 				       &self->priv->viewer->image_area,
-				       event->region,
+				       NULL,
 				       gth_image_viewer_get_zoom_quality_filter (self->priv->viewer));
 }
 
 
 static void
-gth_image_selector_expose (GthImageViewerTool *base,
-			   GdkEventExpose     *event,
-			   cairo_t            *cr)
+gth_image_selector_draw (GthImageViewerTool *base,
+			 cairo_t            *cr)
 {
 	GthImageSelector *self = GTH_IMAGE_SELECTOR (base);
 
@@ -713,13 +705,13 @@ gth_image_selector_expose (GthImageViewerTool *base,
 
 	if (self->priv->mask_visible) {
 		if (self->priv->viewer->dragging)
-			paint_image (self, event, cr);
+			paint_image (self, cr);
 		else
-			paint_background (self, event, cr);
-		paint_selection (self, event, cr);
+			paint_background (self, cr);
+		paint_selection (self, cr);
 	}
 	else
-		paint_image (self, event, cr);
+		paint_image (self, cr);
 }
 
 
@@ -732,9 +724,9 @@ selector_to_real (GthImageSelector *self,
 
 
 static void
-convert_to_real_selection (GthImageSelector *self,
-			   GdkRectangle      selection_area,
-			   GdkRectangle     *real_area)
+convert_to_real_selection (GthImageSelector      *self,
+			   cairo_rectangle_int_t  selection_area,
+			   cairo_rectangle_int_t *real_area)
 {
 	real_area->x = selector_to_real (self, selection_area.x);
 	real_area->y = selector_to_real (self, selection_area.y);
@@ -794,10 +786,10 @@ gth_image_selector_button_release (GthImageViewerTool *base,
 
 
 static void
-grow_upward (GdkRectangle *bound,
-	     GdkRectangle *r,
-	     int           dy,
-	     gboolean      check)
+grow_upward (cairo_rectangle_int_t *bound,
+	     cairo_rectangle_int_t *r,
+	     int                    dy,
+	     gboolean               check)
 {
 	if (check && (r->y + dy < 0))
 		dy = -r->y;
@@ -807,10 +799,10 @@ grow_upward (GdkRectangle *bound,
 
 
 static void
-grow_downward (GdkRectangle *bound,
-	       GdkRectangle *r,
-	       int           dy,
-	       gboolean      check)
+grow_downward (cairo_rectangle_int_t *bound,
+	       cairo_rectangle_int_t *r,
+	       int                    dy,
+	       gboolean               check)
 {
 	if (check && (r->y + r->height + dy > bound->height))
 		dy = bound->height - (r->y + r->height);
@@ -819,10 +811,10 @@ grow_downward (GdkRectangle *bound,
 
 
 static void
-grow_leftward (GdkRectangle *bound,
-	       GdkRectangle *r,
-	       int           dx,
-	       gboolean      check)
+grow_leftward (cairo_rectangle_int_t *bound,
+	       cairo_rectangle_int_t *r,
+	       int                    dx,
+	       gboolean               check)
 {
 	if (check && (r->x + dx < 0))
 		dx = -r->x;
@@ -832,10 +824,10 @@ grow_leftward (GdkRectangle *bound,
 
 
 static void
-grow_rightward (GdkRectangle *bound,
-		GdkRectangle *r,
-		int           dx,
-		gboolean      check)
+grow_rightward (cairo_rectangle_int_t *bound,
+		cairo_rectangle_int_t *r,
+		int                    dx,
+		gboolean               check)
 {
 	if (check && (r->x + r->width + dx > bound->width))
 		dx = bound->width - (r->x + r->width);
@@ -879,8 +871,8 @@ bind_dimension (int dimension,
 
 
 static gboolean
-check_and_set_new_selection (GthImageSelector *self,
-			     GdkRectangle      new_selection)
+check_and_set_new_selection (GthImageSelector      *self,
+			     cairo_rectangle_int_t  new_selection)
 {
 	new_selection.width = MAX (0, new_selection.width);
 	new_selection.height = MAX (0, new_selection.height);
@@ -941,7 +933,7 @@ gth_image_selector_button_press (GthImageViewerTool *base,
 	y = event->y + self->priv->viewer->y_offset;
 
 	if (self->priv->current_area == NULL) {
-		GdkRectangle new_selection;
+		cairo_rectangle_int_t new_selection;
 
 		new_selection.x = selector_to_real (self, x - self->priv->viewer->image_area.x);
 		new_selection.y = selector_to_real (self, y - self->priv->viewer->image_area.y);
@@ -977,12 +969,12 @@ gth_image_selector_button_press (GthImageViewerTool *base,
 static void
 update_mouse_selection (GthImageSelector *self)
 {
-	gboolean          check = ! self->priv->use_ratio;
-	int               dx, dy;
-	GdkRectangle      new_selection, tmp;
-	int               semiplane;
-	GthEventAreaType  area_type = self->priv->current_area->id;
-	EventArea        *event_area;
+	gboolean               check = ! self->priv->use_ratio;
+	int                    dx, dy;
+	cairo_rectangle_int_t  new_selection, tmp;
+	int                    semiplane;
+	GthEventAreaType       area_type = self->priv->current_area->id;
+	EventArea             *event_area;
 
 	dx = selector_to_real (self, self->priv->viewer->drag_x - self->priv->viewer->drag_x_start);
 	dy = selector_to_real (self, self->priv->viewer->drag_y - self->priv->viewer->drag_y_start);
@@ -1396,17 +1388,18 @@ gth_image_selector_motion_notify (GthImageViewerTool *base,
 		|| (abs (self->priv->viewer->drag_y - self->priv->viewer->drag_y_prev) > DRAG_THRESHOLD))
 	    && (self->priv->current_area != NULL))
 	{
-		int retval;
+		GdkGrabStatus retval;
 
-		retval = gdk_pointer_grab (gtk_widget_get_window (widget),
-					   FALSE,
-					   (GDK_POINTER_MOTION_MASK
-					    | GDK_POINTER_MOTION_HINT_MASK
-					    | GDK_BUTTON_RELEASE_MASK),
-					   NULL,
-					   self->priv->current_area->cursor,
-					   event->time);
-		if (retval == 0)
+		retval = gdk_device_grab (event->device,
+					  gtk_widget_get_window (widget),
+					  GDK_OWNERSHIP_WINDOW,
+					  FALSE,
+					  (GDK_POINTER_MOTION_MASK
+					   | GDK_POINTER_MOTION_HINT_MASK
+					   | GDK_BUTTON_RELEASE_MASK),
+					  self->priv->current_area->cursor,
+					  event->time);
+		if (retval == GDK_GRAB_SUCCESS)
 			self->priv->viewer->dragging = TRUE;
 
 		return FALSE;
@@ -1491,8 +1484,8 @@ gth_image_selector_image_changed (GthImageViewerTool *base)
 static void
 gth_image_selector_zoom_changed (GthImageViewerTool *base)
 {
-	GthImageSelector *self = GTH_IMAGE_SELECTOR (base);
-	GdkRectangle      selection;
+	GthImageSelector      *self = GTH_IMAGE_SELECTOR (base);
+	cairo_rectangle_int_t  selection;
 
 	gth_image_selector_get_selection (self, &selection);
 	set_selection (self, selection, TRUE);
@@ -1500,7 +1493,7 @@ gth_image_selector_zoom_changed (GthImageViewerTool *base)
 
 
 static void
-gth_image_selector_instance_init (GthImageSelector *self)
+gth_image_selector_init (GthImageSelector *self)
 {
 	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_IMAGE_SELECTOR, GthImageSelectorPrivate);
 
@@ -1525,7 +1518,7 @@ gth_image_selector_finalize (GObject *object)
 	cairo_surface_destroy (self->priv->surface);
 
 	/* Chain up */
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_image_selector_parent_class)->finalize (object);
 }
 
 
@@ -1534,7 +1527,6 @@ gth_image_selector_class_init (GthImageSelectorClass *class)
 {
 	GObjectClass *gobject_class;
 
-	parent_class = g_type_class_peek_parent (class);
 	g_type_class_add_private (class, sizeof (GthImageSelectorPrivate));
 
 	gobject_class = (GObjectClass*) class;
@@ -1588,7 +1580,7 @@ gth_image_selector_class_init (GthImageSelectorClass *class)
 
 
 static void
-gth_image_selector_gth_image_tool_interface_init (GthImageViewerToolIface *iface)
+gth_image_selector_gth_image_tool_interface_init (GthImageViewerToolInterface *iface)
 {
 	iface->set_viewer = gth_image_selector_set_viewer;
 	iface->unset_viewer = gth_image_selector_unset_viewer;
@@ -1597,7 +1589,7 @@ gth_image_selector_gth_image_tool_interface_init (GthImageViewerToolIface *iface
 	iface->size_allocate = gth_image_selector_size_allocate;
 	iface->map = gth_image_selector_map;
 	iface->unmap = gth_image_selector_unmap;
-	iface->expose = gth_image_selector_expose;
+	iface->draw = gth_image_selector_draw;
 	iface->button_press = gth_image_selector_button_press;
 	iface->button_release = gth_image_selector_button_release;
 	iface->motion_notify = gth_image_selector_motion_notify;
@@ -1606,40 +1598,6 @@ gth_image_selector_gth_image_tool_interface_init (GthImageViewerToolIface *iface
 }
 
 
-GType
-gth_image_selector_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthImageSelectorClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_image_selector_class_init,
-			NULL,
-			NULL,
-			sizeof (GthImageSelector),
-			0,
-			(GInstanceInitFunc) gth_image_selector_instance_init
-		};
-		static const GInterfaceInfo gth_image_tool_info = {
-			(GInterfaceInitFunc) gth_image_selector_gth_image_tool_interface_init,
-			(GInterfaceFinalizeFunc) NULL,
-			NULL
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-					       "GthImageSelector",
-					       &type_info,
-					       0);
-		g_type_add_interface_static (type, GTH_TYPE_IMAGE_VIEWER_TOOL, &gth_image_tool_info);
-	}
-
-	return type;
-}
-
-
 GthImageViewerTool *
 gth_image_selector_new (GthSelectorType type)
 {
@@ -1656,7 +1614,7 @@ gboolean
 gth_image_selector_set_selection_x (GthImageSelector *self,
 				    int               x)
 {
-	GdkRectangle new_selection;
+	cairo_rectangle_int_t new_selection;
 
 	new_selection = self->priv->selection;
 	new_selection.x = x;
@@ -1668,7 +1626,7 @@ gboolean
 gth_image_selector_set_selection_y (GthImageSelector *self,
 				    int               y)
 {
-	GdkRectangle new_selection;
+	cairo_rectangle_int_t new_selection;
 
 	new_selection = self->priv->selection;
 	new_selection.y = y;
@@ -1681,7 +1639,7 @@ gth_image_selector_set_selection_pos (GthImageSelector *self,
 				      int               x,
 				      int               y)
 {
-	GdkRectangle new_selection;
+	cairo_rectangle_int_t new_selection;
 
 	new_selection = self->priv->selection;
 	new_selection.x = x;
@@ -1694,7 +1652,7 @@ gboolean
 gth_image_selector_set_selection_width (GthImageSelector *self,
 					int               width)
 {
-	GdkRectangle new_selection;
+	cairo_rectangle_int_t new_selection;
 
 	new_selection = self->priv->selection;
 	new_selection.width = width;
@@ -1708,7 +1666,7 @@ gboolean
 gth_image_selector_set_selection_height (GthImageSelector *self,
 					 int               height)
 {
-	GdkRectangle new_selection;
+	cairo_rectangle_int_t new_selection;
 
 	new_selection = self->priv->selection;
 	new_selection.height = height;
@@ -1719,16 +1677,16 @@ gth_image_selector_set_selection_height (GthImageSelector *self,
 
 
 void
-gth_image_selector_set_selection (GthImageSelector *self,
-				  GdkRectangle      selection)
+gth_image_selector_set_selection (GthImageSelector      *self,
+				  cairo_rectangle_int_t  selection)
 {
 	set_selection (self, selection, FALSE);
 }
 
 
 void
-gth_image_selector_get_selection (GthImageSelector *self,
-				  GdkRectangle     *selection)
+gth_image_selector_get_selection (GthImageSelector      *self,
+				  cairo_rectangle_int_t *selection)
 {
 	selection->x = MAX (self->priv->selection.x, 0);
 	selection->y = MAX (self->priv->selection.y, 0);
@@ -1846,7 +1804,7 @@ gth_image_selector_bind_dimensions (GthImageSelector *self,
 void
 gth_image_selector_center (GthImageSelector *self)
 {
-	GdkRectangle new_selection;
+	cairo_rectangle_int_t new_selection;
 
 	new_selection = self->priv->selection;
 	new_selection.x = (self->priv->surface_area.width - new_selection.width) / 2;
