@@ -55,7 +55,7 @@ struct _GthTimeSelectorPrivate
 static guint gth_time_selector_signals[LAST_SIGNAL] = { 0 };
 
 
-G_DEFINE_TYPE (GthTimeSelector, gth_time_selector, GTK_TYPE_HBOX);
+G_DEFINE_TYPE (GthTimeSelector, gth_time_selector, GTK_TYPE_BOX);
 
 
 static void
@@ -100,6 +100,8 @@ gth_time_selector_init (GthTimeSelector *self)
 	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_TIME_SELECTOR, GthTimeSelectorPrivate);
 	self->priv->date_time = gth_datetime_new ();
 	self->priv->use_time = TRUE;
+
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (self), GTK_ORIENTATION_HORIZONTAL);
 }
 
 
@@ -163,8 +165,7 @@ show_calendar_popup (GthTimeSelector *self)
 			 (GDK_BUTTON_PRESS_MASK
 			  | GDK_BUTTON_RELEASE_MASK
 			  | GDK_POINTER_MOTION_HINT_MASK
-			  | GDK_BUTTON_MOTION_MASK
-			  | GDK_EXTENSION_EVENTS_ALL),
+			  | GDK_BUTTON_MOTION_MASK),
 			 NULL,
 			 GDK_CURRENT_TIME);
 	gtk_widget_grab_focus (self->priv->calendar);
@@ -212,6 +213,8 @@ update_view_from_data (GthTimeSelector *self)
 			text = gth_datetime_strftime (self->priv->date_time, "%X");
 			entry = gtk_bin_get_child (GTK_BIN (self->priv->time_combo_box));
 			gtk_entry_set_text (GTK_ENTRY (entry), text);
+
+			g_free (text);
 		}
 		else {
 			GtkWidget *entry;
